#
# spec file for package perl-Inline-C
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Inline-C
Name:           perl-Inline-C
Version:        0.820.0
Release:        1699.1.pm.3
# 0.82 -> normalize -> 0.820.0
%define cpan_version 0.82
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        C Language Support for Inline
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/E/ET/ETJ/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(ExtUtils::MakeMaker) >= 7.00
BuildRequires:  perl(File::Copy::Recursive)
BuildRequires:  perl(File::ShareDir::Install) >= 0.06
BuildRequires:  perl(Inline) >= 0.86
BuildRequires:  perl(Parse::RecDescent) >= 1.967009
BuildRequires:  perl(Pegex) >= 0.660
BuildRequires:  perl(Test::More) >= 0.88
BuildRequires:  perl(Test::Warn) >= 0.23
BuildRequires:  perl(YAML::XS)
BuildRequires:  perl(autodie)
BuildRequires:  perl(version) >= 0.77
Requires:       perl(ExtUtils::MakeMaker) >= 7.00
Requires:       perl(Inline) >= 0.86
Requires:       perl(Parse::RecDescent) >= 1.967009
Requires:       perl(Pegex) >= 0.660
Provides:       perl(Inline::C) = %{version}
Provides:       perl(Inline::C::Parser)
Provides:       perl(Inline::C::Parser::Pegex)
Provides:       perl(Inline::C::Parser::Pegex::AST)
Provides:       perl(Inline::C::Parser::Pegex::Grammar)
Provides:       perl(Inline::C::Parser::RecDescent)
Provides:       perl(Inline::C::Parser::RegExp)
%undefine       __perllib_provides
%{perl_requires}

%description
'Inline::C' is a module that allows you to write Perl subroutines in C.
Since version 0.30 the Inline module supports multiple programming
languages and each language has its own support module. This document
describes how to use Inline with the C programming language. It also goes a
bit into Perl C internals.

If you want to start working with programming examples right away, check
out Inline::C::Cookbook. For more information on Inline in general, see
Inline.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes CONTRIBUTING example README
%license LICENSE

%changelog
* Thu Mar  3 2022 Tina Müller <timueller+perl@suse.de>
- updated to 0.82
  see /usr/share/doc/packages/perl-Inline-C/Changes
  0.82 Wed  2 Mar 15:36:50 GMT 2022
  - full release of -I to sub-Perls
  - doc improvements from @oodler577
  0.81_001 Sun Jan 12 12:07:20 PST 2020
  - Pass on correct -I flags to sub-Perls
* Sun May 12 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.81
  see /usr/share/doc/packages/perl-Inline-C/Changes
  0.81 Sat 11 May 2019 12:46:41 PM CEST
  - test - Adjust excpected number of lines in log to Inline-0.82_001 (PR#89
    @ppisar++)
  - Fix pod document link (PR#68 PR#90 @manwar++)
  - Fix docs to work with strict mode (use Inline 'C'; instead of use Inline
    C;) (PR#70 @akarelas-pt++)
  - Add test, and Cookbook example, of array-ref arg (PR#39 @mohawk2++)
* Fri Apr 19 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.80
  see /usr/share/doc/packages/perl-Inline-C/Changes
  0.80 Thu 18 Apr 2019 10:42:30 AM CEST
  - Apply PR#71 (ETJ++) Support perl 5.8.1 again
  - Apply PR#74 and PR#76 (WBRASWELL++) Fix Include Dir Behavior, replace -I
    with -iquote or -I- respectively
  - Apply PR#77 (WBRASWELL++) Fix Include Dir Behavior, Non-GCC Compilers
  - More fixes for include dir behaviour (@sisyphus++)
* Wed May 31 2017 coolo@suse.com
- updated to 0.78
  see /usr/share/doc/packages/perl-Inline-C/Changes
  0.78 Tue 30 May 22:56:30 CEST 2017
  - Apply PR#66 (TINITA++) Remove system calls `rm` and `diff`
* Tue May 16 2017 coolo@suse.com
- updated to 0.77
  see /usr/share/doc/packages/perl-Inline-C/Changes
* Thu Jul  2 2015 coolo@suse.com
- updated to 0.76
  see /usr/share/doc/packages/perl-Inline-C/Changes
* Mon Jun 15 2015 malcolmlewis@opensuse.org
- Updated to version 0.75:
  + See /usr/share/doc/packages/perl-Inline-C/Changes.
- Drop Inline-CPR-0.12.diff as not needed with new version.
- Drop perl-Inline-C-0.12-implicit.diff as not needed with new
  version.
- Spec file clean up.
* Wed Mar 16 2011 cfarrell@novell.com
- license update: GPL+ or Artistic.
  License indiLicense indication comes from CPR.pod (same terms as
  Perl which is GPL+ or Artistic as per our rpm spec file license
  syntax).
* Mon Dec  6 2010 coolo@novell.com
- readd patch that was lost in build service magic
* Tue Nov 30 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Fri Jan 26 2007 anicka@suse.cz
- compile with $RPM_OPT_FLAGS and fix implicit definitions of
  special functions
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Thu Jul 17 2003 freitag@suse.de
- used vendor macros and perl_process_packlist in filelist
* Sun May 25 2003 ro@suse.de
- remove unpackaged files from buildroot
* Tue Dec  3 2002 freitag@suse.de
- new package version
